==> dsgui-1.0-rc1.tar.gz: dsgui-1.0-rc1/configuration.py <==
#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA


class ConfigManager(object):
  """singleton style class for management of configuration"""
  
  # the following are used in setup of CERTIFICATE_VALIDATION_DATE
  DOWNLOAD_DATE = 1
  CURRENT_DATE = 2
  
  allowed_attributes = ('AUTO_DOWNLOAD_WHOLE_MESSAGES',
                        'DEFAULT_DOWNLOAD_SIGNED',
                        'STORE_PASSWORDS_ON_DISK',
                        'STORE_MESSAGES_ON_DISK',
                        'STORE_ADDITIONAL_DATA_ON_DISK',
                        'CERTIFICATE_VALIDATION_DATE',
                        'CHECK_CRL')
  
  AUTO_DOWNLOAD_WHOLE_MESSAGES = False #
  DEFAULT_DOWNLOAD_SIGNED = True # default downloading method
  STORE_PASSWORDS_ON_DISK = True # should password be saved or always asked
  STORE_MESSAGES_ON_DISK = True # when False memory is used - non persistent
  STORE_ADDITIONAL_DATA_ON_DISK = True # account info and last check
  CERTIFICATE_VALIDATION_DATE = DOWNLOAD_DATE
  CHECK_CRL = True

  @classmethod
  def set_config(cls, attr, value):
    assert attr in cls.allowed_attributes
    setattr(cls, attr, value)
    
  @classmethod
  def save_to_config(cls, config):
    section = "preferences"
    config.add_section(section)
    for attr in cls.allowed_attributes:
      config.set(section, attr, getattr(cls, attr))

  @classmethod
  def load_from_config(cls, config):
    section = "preferences"
    if config.has_section(section):
      for attr in cls.allowed_attributes:
        if config.has_option(section, attr):
          try:
            if attr == "CERTIFICATE_VALIDATION_DATE":
              cls.set_config(attr, config.getint(section, attr))
            else:
              cls.set_config(attr, config.getboolean(section, attr))
          except ValueError:
            # ignore invalid values
            pass
  
import pygtk
import gtk
pygtk.require("2.0")
import os


class ConfigDialog(object):

  attr_to_oid = (('AUTO_DOWNLOAD_WHOLE_MESSAGES','download_whole_messages'),
                 ('DEFAULT_DOWNLOAD_SIGNED','download_signed'),
                 ('STORE_PASSWORDS_ON_DISK','store_password'),
                 ('STORE_MESSAGES_ON_DISK','store_messages'),
                 ('STORE_ADDITIONAL_DATA_ON_DISK','store_additional_data'),
                 ('CHECK_CRL','check_crl'))

  def __init__(self, parent):
    """
    client = dslib client instance
    """
    self.parent = parent
    self.builder = gtk.Builder()
    gui_xml = self.parent.fix_ui_xml("config_dialog.ui")
    try:
      self.builder.add_from_string(gui_xml.decode('utf-8'))
    except:
      # this fixes problem with different API on windows and PyGTK 2.12
      self.builder.add_from_string(gui_xml.decode('utf-8'), -1)
    self.builder.connect_signals(self)
    self.dialog = self.builder.get_object("config_dialog")
    self._fill_data_from_manager()
    self.builder.get_object("download_whole_messages").toggled()
    self.changed = []

  def run(self):
    result = self.dialog.run()
    if result == 1:
      self._set_data_to_manager()
    return result

  def destroy(self):
    self.dialog.destroy()

  def hide(self):
    self.dialog.hide()
    
  def show_all(self):
    self.dialog.show_all()
    
  # Callbacks
  
  def on_download_whole_messages_toggled(self, w):
    self.builder.get_object("download_signed").set_sensitive(w.get_active())

  # // end of Callbacks
  
  def _fill_data_from_manager(self):
    for attr, oid in self.attr_to_oid:
      widget = self.builder.get_object(oid)
      value = getattr(ConfigManager, attr)
      widget.set_active(value)
    if ConfigManager.CERTIFICATE_VALIDATION_DATE == ConfigManager.DOWNLOAD_DATE:
      self.builder.get_object("check_against_download_date").set_active(True)
    else:
      self.builder.get_object("check_against_current_date").set_active(True)
      
  
  def _set_data_to_manager(self):
    for attr, oid in self.attr_to_oid:
      widget = self.builder.get_object(oid)
      old_value = getattr(ConfigManager, attr)
      new_value = widget.get_active()
      if old_value != new_value:
        # value of this attribute has changed
        self.changed.append(attr)
        ConfigManager.set_config(attr, new_value)
    if self.builder.get_object("check_against_download_date").get_active():
      new_value = ConfigManager.DOWNLOAD_DATE
    else:
      new_value = ConfigManager.CURRENT_DATE
    if new_value != ConfigManager.CERTIFICATE_VALIDATION_DATE:
      self.changed.append("CERTIFICATE_VALIDATION_DATE")
      ConfigManager.set_config("CERTIFICATE_VALIDATION_DATE", new_value)

==> dsgui-1.1.2.tar.gz: dsgui-1.1.2/configuration.py <==
#*    dsgui - a graphical user interface for Datove schranky
#*    Copyright (C) 2009-2010  CZ.NIC, z.s.p.o. (http://www.nic.cz)
#*
#*    This library is free software; you can redistribute it and/or
#*    modify it under the terms of the GNU Library General Public
#*    License as published by the Free Software Foundation; either
#*    version 2 of the License, or (at your option) any later version.
#*
#*    This library is distributed in the hope that it will be useful,
#*    but WITHOUT ANY WARRANTY; without even the implied warranty of
#*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#*    Library General Public License for more details.
#*
#*    You should have received a copy of the GNU Library General Public
#*    License along with this library; if not, write to the Free
#*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA


class ConfigManager(object):
  """singleton style class for management of configuration"""
  
  # the following are used in setup of CERTIFICATE_VALIDATION_DATE
  DOWNLOAD_DATE = 1
  CURRENT_DATE = 2
  
  DATE_FORMAT_DEFAULT = 3
  DATE_FORMAT_ISO = 2
  DATE_FORMAT_LOCALE = 1
  #DATE_FORMAT_CUSTOM = 4
  
  allowed_attributes = ('AUTO_DOWNLOAD_WHOLE_MESSAGES',
                        'DEFAULT_DOWNLOAD_SIGNED',
                        #'STORE_PASSWORDS_ON_DISK',
                        'STORE_MESSAGES_ON_DISK',
                        'STORE_ADDITIONAL_DATA_ON_DISK',
                        'CERTIFICATE_VALIDATION_DATE',
                        'CHECK_CRL',
                        'CHECK_NEW_VERSIONS',
                        'DATE_FORMAT')
  
  AUTO_DOWNLOAD_WHOLE_MESSAGES = False #
  DEFAULT_DOWNLOAD_SIGNED = True # default downloading method
  STORE_PASSWORDS_ON_DISK = False # should password be saved or always asked
                                  # this is the default value only
                                  # as it is adjustable per-account
  STORE_MESSAGES_ON_DISK = True # when False memory is used - non persistent
  STORE_ADDITIONAL_DATA_ON_DISK = True # account info and last check
  CERTIFICATE_VALIDATION_DATE = DOWNLOAD_DATE
  CHECK_CRL = True
  CHECK_NEW_VERSIONS = True
  DATE_FORMAT = DATE_FORMAT_LOCALE

  @classmethod
  def set_config(cls, attr, value):
    assert attr in cls.allowed_attributes
    setattr(cls, attr, value)
    
  @classmethod
  def save_to_config(cls, config):
    section = "preferences"
    config.add_section(section)
    for attr in cls.allowed_attributes:
      config.set(section, attr, getattr(cls, attr))

  @classmethod
  def load_from_config(cls, config):
    section = "preferences"
    if config.has_section(section):
      for attr in cls.allowed_attributes:
        if config.has_option(section, attr):
          try:
            if attr in ("CERTIFICATE_VALIDATION_DATE","DATE_FORMAT"):
              cls.set_config(attr, config.getint(section, attr))
            else:
              cls.set_config(attr, config.getboolean(section, attr))
          except ValueError:
            # ignore invalid values
            pass
    # always use signed method
    cls.set_config("DEFAULT_DOWNLOAD_SIGNED", True)
  
import pygtk
import gtk
pygtk.require("2.0")
import os


class ConfigDialog(object):

  attr_to_oid = (('AUTO_DOWNLOAD_WHOLE_MESSAGES','download_whole_messages'),
                 ('DEFAULT_DOWNLOAD_SIGNED','download_signed'),
                 ('STORE_PASSWORDS_ON_DISK','store_password'),
                 ('STORE_MESSAGES_ON_DISK','store_messages'),
                 ('STORE_ADDITIONAL_DATA_ON_DISK','store_additional_data'),
                 ('CHECK_CRL','check_crl'),
                 ('CHECK_NEW_VERSIONS','check_new_versions'),
                 )

  def __init__(self, parent):
    """
    client = dslib client instance
    """
    self.parent = parent
    self.builder = gtk.Builder()
    gui_xml = self.parent.fix_ui_xml("config_dialog.ui")
    try:
      self.builder.add_from_string(gui_xml.decode('utf-8'))
    except:
      # this fixes problem with different API on windows and PyGTK 2.12
      self.builder.add_from_string(gui_xml.decode('utf-8'), -1)
    self.builder.connect_signals(self)
    self.dialog = self.builder.get_object("config_dialog")
    self._fill_data_from_manager()
    self.builder.get_object("download_whole_messages").toggled()
    self.changed = []
    self.dialog.set_transient_for(self.parent.window1)

  def run(self):
    result = self.dialog.run()
    if result == 1:
      self._set_data_to_manager()
    return result

  def destroy(self):
    self.dialog.destroy()

  def hide(self):
    self.dialog.hide()
    
  def show_all(self):
    self.dialog.show_all()
    
  # Callbacks
  
  def on_download_whole_messages_toggled(self, w):
    self.builder.get_object("download_signed").set_sensitive(w.get_active())

  # // end of Callbacks
  
  def _fill_data_from_manager(self):
    for attr, oid in self.attr_to_oid:
      widget = self.builder.get_object(oid)
      value = getattr(ConfigManager, attr)
      widget.set_active(value)
    if ConfigManager.CERTIFICATE_VALIDATION_DATE == ConfigManager.DOWNLOAD_DATE:
      self.builder.get_object("check_against_download_date").set_active(True)
    else:
      self.builder.get_object("check_against_current_date").set_active(True)
      
  
  def _set_data_to_manager(self):
    for attr, oid in self.attr_to_oid:
      widget = self.builder.get_object(oid)
      old_value = getattr(ConfigManager, attr)
      new_value = widget.get_active()
      if old_value != new_value:
        # value of this attribute has changed
        self.changed.append(attr)
        ConfigManager.set_config(attr, new_value)
    if self.builder.get_object("check_against_download_date").get_active():
      new_value = ConfigManager.DOWNLOAD_DATE
    else:
      new_value = ConfigManager.CURRENT_DATE
    if new_value != ConfigManager.CERTIFICATE_VALIDATION_DATE:
      self.changed.append("CERTIFICATE_VALIDATION_DATE")
      ConfigManager.set_config("CERTIFICATE_VALIDATION_DATE", new_value)
